@@ -33,7 +33,7 @@ class DirectoryWalkerGuard(object):
         os.chdir(os.path.pardir)
 
 
-_default_pybind11_repr_re = re.compile(r'<\w+(\.\w+)* object at 0x[0-9a-f]+>')
+_default_pybind11_repr_re = re.compile(r'<\w+(\.\w+)* object at 0x[0-9a-fA-F]+>')
 
 
 def replace_default_pybind11_repr_with_ellipses(line):
@@ -340,7 +340,7 @@ class AttributeStubsGenerator(StubsGenerator):
         _visited_objects.append(self)
 
     def is_safe_to_use_repr(self, value):
-        if isinstance(value, (int, str)):
+        if value is None or isinstance(value, (int, str)):
             return True
         if isinstance(value, (float, complex)):
             try:
